==> inkster-1.0.3.tar.gz: inkster-1.0.3/README.md <==
# Welcome to Inkster!

## Installations

If you would like to install inkster just run the command in a command prompt:

**Python**

```bash
pip install inkster
```

**JavaScript**

```bash
npm install inkster-js
```

## Extra Information

Here is some extra information on inkster.

### Categories/Features

Here are some features for inkster.

- Easy
- Educational

### Socials/Links

Here are some things that you can contact us with.

- Email: `InksterPY@protonmail.com`
- Discord Server: `https://discord.gg/HUFtMsz`
- Documentation: `https://onyocoder.github.io/inkster-documentation/`
- PyPi: `https://pypi.org/project/inkster-OnyoCoder/1.0.1/`
- npmjs: `https://www.npmjs.com/package/inkster-js`

### Contributors

- Onyo#8502 -> Creator of Inkster. (Github: OnyoCoder)
- Lumi#1930 -> Python Version Contributor. (Github: Lumi-Sepiolidae)
- Abxy#4576 -> Python & JS Version Contributor. (Github: AbxyPlayz)

## License

Copyright 2020 OnyoCoder

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> inkster-1.0.4.tar.gz: inkster-1.0.4/README.md <==
# Welcome to Inkster!

## Installations

If you would like to install inkster just run the command in a command prompt:

**Python**

```bash
pip install inkster
```

**JavaScript**

```bash
npm install inkster-js
```

## Extra Information

Here is some extra information on inkster.

### Categories/Features

Here are some features for inkster.

- Easy
- Educational

### Socials/Links

Here are some things that you can contact us with.

- Email: `InksterPY@protonmail.com`
- Discord Server: `https://discord.gg/HUFtMsz`
- Documentation: `https://onyocoder.github.io/inkster-documentation/`
- PyPi: `https://pypi.org/project/inkster/`
- npmjs: `https://www.npmjs.com/package/inkster-js`

### Contributors

- Onyo#8502 -> Creator of Inkster. (Github: OnyoCoder)
- Lumi#1930 -> Python Version Contributor. (Github: Lumi-Sepiolidae)
- Abxy#4576 -> Python & JS Version Contributor. (Github: AbxyPlayz)

## License

Copyright 2020 OnyoCoder

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
